@@ -109,11 +109,11 @@ public:
         const auto pluginName = plugin.pluginId();
         qCDebug(KAMD_LOG_APPLICATION) << "Plugin Name is " << pluginName << plugin.fileName();
 
-        if (pluginName == "org.kde.ActivityManager.ResourceScoring") {
+        if (pluginName == QLatin1String("org.kde.ActivityManager.ResourceScoring")) {
             // SQLite plugin is necessary for the proper workspace behaviour
             return true;
         } else {
-            return config.readEntry(pluginName + "Enabled", plugin.isEnabledByDefault());
+            return config.readEntry(pluginName + QStringLiteral("Enabled"), plugin.isEnabledByDefault());
         }
     }
 
@@ -154,7 +154,7 @@ void Application::init()
 
     QMetaObject::invokeMethod(this, "loadPlugins", Qt::QueuedConnection);
 
-    QDBusConnection::sessionBus().registerObject("/ActivityManager", this,
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/ActivityManager"), this,
             QDBusConnection::ExportAllSlots);
 }
 
@@ -288,31 +288,6 @@ QString Application::serviceVersion() const
     return KACTIVITIES_VERSION_STRING;
 }
 
-// Leaving object oriented world :)
-
-namespace  {
-    template <typename Return>
-    Return callOnRunningService(const QString &method)
-    {
-        static QDBusInterface remote(KAMD_DBUS_SERVICE, "/ActivityManager",
-                                     "org.kde.ActivityManager.Application");
-        QDBusReply<Return> reply = remote.call(method);
-
-        return (Return)reply;
-    }
-
-    QString runningServiceVersion()
-    {
-        return callOnRunningService<QString>("serviceVersion");
-    }
-
-    bool isServiceRunning()
-    {
-        return QDBusConnection::sessionBus().interface()->isServiceRegistered(
-                KAMD_DBUS_SERVICE);
-    }
-}
-
 int main(int argc, char **argv)
 {
     // Disable session management for this process
@@ -325,94 +300,11 @@ int main(int argc, char **argv)
     application.setOrganizationDomain(QStringLiteral("kde.org"));
 
     KCrash::initialize();
+    KDBusService service(KDBusService::Unique);
 
-    const auto arguments = application.arguments();
+    application.init();
 
-    if (arguments.size() == 0) {
-        QCoreApplication::exit(EXIT_FAILURE);
-
-    } else if (arguments.size() != 1 && (arguments.size() != 2 || arguments[1] == "--help")) {
-
-        QTextStream(stdout)
-            << "start\tStarts the service\n"
-            << "stop\tStops the server\n"
-            << "status\tPrints basic server information\n"
-            << "start-daemon\tStarts the service without forking (use with caution)\n"
-            << "--help\tThis help message\n";
-
-        QCoreApplication::exit(EXIT_SUCCESS);
-
-    } else if (arguments.size() == 1 || arguments[1] == "start") {
-
-        // Checking whether the service is already running
-        if (isServiceRunning()) {
-            QTextStream(stdout) << "Already running\n";
-            QCoreApplication::exit(EXIT_SUCCESS);
-        }
-
-        // Creating the watcher, but not on the wall
-
-        QDBusServiceWatcher watcher(KAMD_DBUS_SERVICE,
-                                    QDBusConnection::sessionBus(),
-                                    QDBusServiceWatcher::WatchForRegistration);
-
-        QObject::connect(&watcher, &QDBusServiceWatcher::serviceRegistered,
-            [] (const QString &service) {
-                QTextStream(stdout)
-                    << "Service started, version: " << runningServiceVersion()
-                    << "\n";
-
-                QCoreApplication::exit(EXIT_SUCCESS);
-            });
-
-        // Starting the dameon
-
-        QProcess::startDetached(
-                KAMD_FULL_BIN_DIR "/kactivitymanagerd",
-                QStringList{"start-daemon"}
-            );
-
-        return application.exec();
-
-    } else if (arguments[1] == "stop") {
-        if (!isServiceRunning()) {
-            QTextStream(stdout) << "Service not running\n";
-            QCoreApplication::exit(EXIT_SUCCESS);
-        }
-
-        callOnRunningService<void>("quit");
-
-        QTextStream(stdout) << "Service stopped\n";
-
-        return EXIT_SUCCESS;
-
-    } else if (arguments[1] == "status") {
-
-        // Checking whether the service is already running
-        if (isServiceRunning()) {
-            QTextStream(stdout) << "The service is running, version: "
-                                << runningServiceVersion() << "\n";
-        } else {
-            QTextStream(stdout) << "The service is not running\n";
-
-        }
-
-        return EXIT_SUCCESS;
-
-    } else if (arguments[1] == "start-daemon") {
-        // Really starting the activity manager
-
-        KDBusService service(KDBusService::Unique);
-
-        application.init();
-
-        return application.exec();
-
-    } else {
-        QTextStream(stdout) << "Unrecognized command: " << arguments[1] << '\n';
-
-        return EXIT_FAILURE;
-    }
+    return application.exec();
 }
 
 QStringList Application::loadedPlugins() const
