@@ -29,10 +29,10 @@ class EventSpyPlugin : public Plugin {
     Q_OBJECT
 
 public:
-    explicit EventSpyPlugin(QObject *parent = Q_NULLPTR, const QVariantList &args = QVariantList());
-    ~EventSpyPlugin() Q_DECL_OVERRIDE;
+    explicit EventSpyPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    ~EventSpyPlugin() override;
 
-    bool init(QHash<QString, QObject *> &modules) Q_DECL_OVERRIDE;
+    bool init(QHash<QString, QObject *> &modules) override;
 
 private Q_SLOTS:
     void directoryUpdated(const QString &dir);
